@@ -108,7 +108,7 @@ app.run()
 '''
 #cloo = turn_to_model(['my','name','is','john'])
 #things = ['my','name']
-def generation(things,cloo,prog = False):
+def generation(things,cloo,prog = False,length = 'infinite'):
     global cool
     oof=' '
     while True:
@@ -126,6 +126,9 @@ def generation(things,cloo,prog = False):
         if prog:
             print(oof.join(things))
         cool = oof.join(things)
+        if length!='infinite':
+            if len(things)>length:
+                return oof.join(things)
     return oof.join(things)
 #mlode = json.load(open('modelo.json','r'))
 #generation(things=things,cloo=mlode)
